@@ -1,8 +1,8 @@
 /*
  * profile.h - methods and structs for work with profile data
- * This file is part of libvkontakte library
+ * This file is part of MySocials driver library
  *
- * Copyright (C) 2010 - Kirill Kulakov
+ * Copyright (C) 2010 - MySocials team
  *
  * libvkontakte library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,9 @@
 #define _PROFILE_H_
 
 #include <glib.h>
+#include <libxml/tree.h>
 
-//#define DEBUG
+#define DEBUG
 #ifdef DEBUG
 #define msa_debug(...) g_debug(__VA_ARGS__)
 #define msa_warning(...) g_warning(__VA_ARGS__)
@@ -38,8 +39,6 @@
  */
 struct ProfileData {
     gchar *id;
-    gchar *login;
-    gchar *password;
     gchar *remixmid;
     gchar *remixsid;
     gchar *secret;
@@ -74,4 +73,27 @@ void profile_remove(struct ProfileData *data);
  */
 const struct ProfileData *profile_get_by_id(gchar *id);
 
+/**
+ * update selected profile, using settings from xml
+ *
+ * @param data - pointer to selected profile
+ * @return 0 on success, 1 - otherwise
+ */
+int profile_update(struct ProfileData *data, xmlDocPtr settings);
+
+/**
+ * checks profiles parameters
+ *
+ * @param data - pointer to selected profile
+ * @return 0 on success, 1 - otherwise
+ */
+int profile_check(const struct ProfileData *data);
+
+/**
+ * get profiles parameters
+ *
+ * @param data - pointer to selected profile 
+ */
+gchar** profile_get_params(const struct ProfileData *data);
+
 #endif
